@@ -105,15 +105,16 @@ class TestCommandPlugin(VenvAwareCommand, ApplicationPlugin):
 
     app: Application
     tests: list[Test]
+    requires_venv: t.ClassVar[bool] = False
 
     name = "test"
     arguments = [
         argument("test", "One or more tests to run (runs all if none are specified)", optional=True, multiple=True),
     ]
-    options = [
+    options = VenvAwareCommand.options + [
         option(
             "--no-line-prefix",
-            "s",
+            "-s",
             description="Do not prefix output from the test commands with the test name (default if a single argument "
             "for <info>test</info> is specified).",
         ),
@@ -122,8 +123,17 @@ class TestCommandPlugin(VenvAwareCommand, ApplicationPlugin):
             "-l",
             description="List all available tests",
         ),
+        option(
+            "--exclude",
+            "-x",
+            description="Do not run the specified test. Can be passed multiple times.",
+            flag=False,
+            multiple=True,
+        ),
     ]
-    options[0]._default = NotSet.Value  # Hack to set a default value for the flag
+
+    # Hack to set a default value for the flag
+    next(opt for opt in options if opt.name == "no-line-prefix")._default = NotSet.Value
 
     def load_configuration(self, app: Application) -> None:
         self.app = app
@@ -151,6 +161,9 @@ class TestCommandPlugin(VenvAwareCommand, ApplicationPlugin):
         return result
 
     def handle(self) -> int:
+        result = super().handle()
+        if result != 0:
+            return result
         if self.option("list"):
             if self.argument("test"):
                 self.line_error("error: incompatible arguments (<opt>test</opt> and <opt>-l,--list</opt>)", "error")
@@ -164,6 +177,7 @@ class TestCommandPlugin(VenvAwareCommand, ApplicationPlugin):
             return 1
 
         test_names: list[str] = self.argument("test")
+        exclude_tests: list[str] = self.option("exclude")
 
         if not test_names:
             tests = set(self.tests)
@@ -174,6 +188,8 @@ class TestCommandPlugin(VenvAwareCommand, ApplicationPlugin):
                 self.line_error(f"error: {exc}", "error")
                 return 1
 
+        tests -= {t for a in exclude_tests for t in self._select_tests(a)}
+
         if (no_line_prefix := self.option("no-line-prefix")) is NotSet.Value:
             no_line_prefix = test_names is not None and len(tests) == 1
 
