@@ -3,10 +3,11 @@ import os
 import shutil
 import string
 import subprocess as sp
+import sys
 import typing as t
 from pathlib import Path
 
-from slap.application import IO, Application, Command, argument, option
+from slap.application import Application, Command, argument, option
 from slap.plugins import ApplicationPlugin
 from slap.python.environment import PythonEnvironment
 
@@ -37,6 +38,19 @@ USER_INIT_SCRIPTS = {
 }
 
 
+def is_relative_to(apath: Path, bpath: Path) -> bool:
+    """Checks if *apath* is a path relative to *bpath*."""
+
+    if sys.version_info[:2] < (3, 9):
+        try:
+            apath.relative_to(bpath)
+            return True
+        except ValueError:
+            return False
+    else:
+        return apath.is_relative_to(bpath)
+
+
 class Venv:
     def __init__(self, directory: Path) -> None:
         self.directory = directory
@@ -118,25 +132,51 @@ class VenvAwareCommand(Command):
     command is executed, it will check if we're currently in a virtual environment. If not, it will activate
     the environment that is considered "active" by the Slap `venv` command."""
 
-    def execute(self, io: IO) -> int:
+    requires_venv: t.ClassVar[bool] = True
+
+    options = [
+        option(
+            "no-venv-check",
+            description="Do not check if the target Python environment is a virtual environment.",
+        ),
+        option(
+            "ignore-active-venv",
+            description="Ignore the currently active VIRTUAL_ENV and act as if it isn't set.",
+        ),
+    ]
+
+    def _deactivate_venv(self) -> None:
+        venv = os.environ.pop("VIRTUAL_ENV", None)
+        if venv:
+            self.line(f"<info>(venv-aware) deactivating current virtual environment (<s>{venv}</s>)</info>")
+            paths = os.getenv("PATH", "").split(os.pathsep)
+            paths = [path for path in paths if not is_relative_to(Path(path), Path(venv))]
+            os.environ["PATH"] = os.pathsep.join(paths)
+
+    def handle(self) -> int:
+        if self.option("no-venv-check"):
+            return 0
+        if self.option("ignore-active-venv"):
+            self._deactivate_venv()
         if os.getenv("VIRTUAL_ENV"):
-            io.error_output.write_line(
-                f'<info>(venv-aware) a virtual environment is already activated (<s>{os.environ["VIRTUAL_ENV"]}</s>)</info>'
+            self.io.error_output.write_line(
+                "<info>(venv-aware) a virtual environment is already activated "
+                f'(<s>{os.environ["VIRTUAL_ENV"]}</s>)</info>'
             )
         else:
             manager = VenvManager()
             venv = manager.get_last_activated()
             if venv:
                 venv.activate()
-                io.error_output.write_line(
+                self.io.error_output.write_line(
                     f'<info>(venv-aware) activating current environment <s>"{venv.name}"</s></info>'
                 )
-            else:
-                io.error_output.write_line(
-                    f"<warning>(venv-aware) there is no current environment that can be activated</warning>"
+            elif self.requires_venv:
+                self.io.error_output.write_line(
+                    "<warning>(venv-aware) there is no current environment that can be activated</warning>"
                 )
-
-        return super().execute(io)
+                return 1
+        return 0
 
 
 class VenvCommand(Command):
@@ -184,7 +224,8 @@ class VenvCommand(Command):
             "--activate",
             "-a",
             description="Activate the environment given by the environment name. Note that using this option if used "
-            "directly with the Slap CLI will cause an error because it needs to be shadowed by a function of your shell.",
+            "directly with the Slap CLI will cause an error because it needs to be shadowed by a function of your "
+            "shell.",
         ),
         option(
             "--create",
@@ -366,7 +407,7 @@ class VenvCommand(Command):
 
         if self.option("delete"):
             if not venv:
-                self.line_error(f"error: missing environment name", "error")
+                self.line_error("error: missing environment name", "error")
                 return 1
             if not venv.exists():
                 self.line_error(f'error: environment <s>"{venv.name}"</s> does not exist', "error")
@@ -388,7 +429,7 @@ class VenvCommand(Command):
                 if venv and self.argument("name"):
                     self.line_error(f'error: environment <s>"{venv.name}"</s> does not exist', "error")
                 else:
-                    self.line_error(f"error: no active environment", "error")
+                    self.line_error("error: no active environment", "error")
                 return 1
             print(venv.directory.absolute())
 
